@@ -2,7 +2,6 @@
 # -*- coding: utf8 -*-
 import os
 import jinja2
-import readline
 from textwrap import wrap
 from os.path import join
 from pythong.util import (ask_yes_no, prompt_input, determine_directories,
@@ -45,13 +44,15 @@ def prompt_new_project(name=None, snap=False):
     project.update(determine_directories(name, os.getcwd(), snap))
 
     # Files
+    project['manifest'] = join(project['project_dir'], "MANIFEST.in")
     project['setup_file'] = join(project['project_dir'], "setup.py")
     project['init_file'] = join(project['source_dir'], "__init__.py")
     if project.get('tests_dir'):
         project['test_init_file'] = join(project['tests_dir'], "__init__.py")
         project['test_file'] = join(project['tests_dir'], name + "_tests.py")
 
-    project['files'] = [project['setup_file'], project['init_file']]
+    project['files'] = [project['manifest'], project['setup_file'],
+                        project['init_file']]
     if project.get('tests_dir'):
         project['files'].extend([project['test_init_file'],
                                  project['test_file']])
@@ -59,18 +60,29 @@ def prompt_new_project(name=None, snap=False):
     # Create project skeleton
     print "Creating structure for new Python project {}.".format(
         project.get("name"))
+    # Create directories
     for dirname in project.get("directories", []):
         try:
             os.mkdir(dirname)
         except OSError as e:
             if e.errno != 17:
                 raise e
+    # Create files
     for f in project.get("files", []):
         try:
             project['init_file'] = open(f, 'w').close()
         except OSError as e:
             if e.errno != 17:
                 raise e
+ 
+    # Write config file before we add all of the setup.py info to
+    # the project dict. We don't want or need that in there. We
+    # only need the directory and file info.
+    try:
+        write_config(os.path.join(project['project_dir'], '.pythong'), project)
+        print "Configuration file written."
+    except:
+        print "Problem writing config file."
 
     # Create setup.py file
     # first, set sane defaults
@@ -105,7 +117,7 @@ def prompt_new_project(name=None, snap=False):
             url=prompt_input("Project URL: "),
             license=prompt_input("License: "),
             requires=[x.strip() for x in
-                      prompt_input("Requirements (comma delimited): ",
+                      prompt_input("Requirements (separate with commas): ",
                                    default="").split(',')]))
         if os.path.exists(project['setup_file']) \
            and os.path.getsize(project['setup_file']) != 0:
@@ -113,11 +125,6 @@ def prompt_new_project(name=None, snap=False):
     else:
         print "Generating skeletal setup files."
 
-    try:
-        write_config(os.path.join(project['project_dir'], '.pythong'), project)
-        print "Configuration file written."
-    except:
-        print "Problem writing config file."
 
     try:
         write_setup_files(project['project_dir'])
@@ -169,9 +176,7 @@ def _do_line_wrap(config_data):
 
 
 def unwrap(inp, maxlen):
-    q.q(maxlen)
     first = wrap(inp, width=maxlen - 1)[0] + ' '
-    q.q(first)
     print first
     return first, inp.rpartition(first)[2]
 
